﻿using System;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Ink;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.Device.Location;
using System.ComponentModel;
using System.Threading;

namespace GeoDemo
{
    public class FakeGeoPositionWatcher : IGeoPositionWatcher<GeoCoordinate>
    {

        private AsyncOperation operation;
        private Timer timer;

        private GeoPosition<GeoCoordinate> position = new GeoPosition<GeoCoordinate>(DateTimeOffset.Now, new GeoCoordinate(45.477827, 9.310956, 0, 30, 30, 0, 0));
        public GeoPosition<GeoCoordinate> Position
        {
            get
            {
                return position;
            }
        }

        public event EventHandler<GeoPositionChangedEventArgs<GeoCoordinate>> PositionChanged;

        public void Start(bool suppressPermissionPrompt)
        {
            if (timer == null)
            {
                operation = AsyncOperationManager.CreateOperation(null);

                timer = new Timer(Raise, null, 0, 5000);

                if (StatusChanged != null)
                    StatusChanged(this, new GeoPositionStatusChangedEventArgs(GeoPositionStatus.Initializing));
                if (StatusChanged != null)
                    StatusChanged(this, new GeoPositionStatusChangedEventArgs(GeoPositionStatus.Ready));
            }
        }

        private void Raise(object s)
        {
            operation.Post(st =>
            {
                this.Position.Location = new GeoCoordinate(this.Position.Location.Latitude,
                    this.Position.Location.Longitude + 0.0002,
                    this.Position.Location.Altitude + 0.0002,
                    Math.Max(2, this.Position.Location.HorizontalAccuracy - 5),
                    Math.Max(2, this.Position.Location.VerticalAccuracy - 5),
                    this.Position.Location.Speed,
                    this.Position.Location.Course);

                if (PositionChanged != null)
                    PositionChanged(this, new GeoPositionChangedEventArgs<GeoCoordinate>(this.Position));
            }, null);
        }

        public void Start()
        {
            this.Start(false);
        }

        public GeoPositionStatus Status
        {
            get;
            set;
        }

        public event EventHandler<GeoPositionStatusChangedEventArgs> StatusChanged;

        public void Stop()
        {
            if (timer != null)
                timer.Dispose();
            timer = null;
        }

        public bool TryStart(bool suppressPermissionPrompt, TimeSpan timeout)
        {
            throw new NotSupportedException();
        }

    }
}
