﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using Microsoft.Phone.Controls;
using System.Device.Location;

namespace GeoDemo
{
    public partial class MainPage : PhoneApplicationPage
    {
        private IGeoPositionWatcher<GeoCoordinate> watcher;

        // Constructor
        public MainPage()
        {
            InitializeComponent();

            this.map.ZoomLevel = 18;
            this.map.Visibility = System.Windows.Visibility.Collapsed;

            InitGeoPositionWatcher();
        }

        private void InitGeoPositionWatcher()
        {
            // Creo il watcher in funzione che sia un emulatore o un device
            if (Microsoft.Devices.Environment.DeviceType == Microsoft.Devices.DeviceType.Device)
            {
                GeoCoordinateWatcher geoWatcher = new GeoCoordinateWatcher(GeoPositionAccuracy.High);
                // Metri
                geoWatcher.MovementThreshold = 20;
                this.watcher = geoWatcher;
            }
            else
            {
                this.watcher = new FakeGeoPositionWatcher();
            }

            // Intercetto gli eventi e avvio
            watcher.StatusChanged += new EventHandler<GeoPositionStatusChangedEventArgs>(watcher_StatusChanged);
            watcher.PositionChanged += new EventHandler<GeoPositionChangedEventArgs<GeoCoordinate>>(watcher_PositionChanged);
            watcher.Start();
        }

        void watcher_PositionChanged(object sender, GeoPositionChangedEventArgs<GeoCoordinate> e)
        {
            this.map.SetView(e.Position.Location, this.map.ZoomLevel);
            this.positionPin.Location = e.Position.Location;

            // this.map.TryLocationToViewportPoint();
        }

        void watcher_StatusChanged(object sender, GeoPositionStatusChangedEventArgs e)
        {
            switch (e.Status)
            {
                case GeoPositionStatus.Disabled:
                    break;
                case GeoPositionStatus.Initializing:
                    break;
                case GeoPositionStatus.NoData:
                    break;
                case GeoPositionStatus.Ready:
                    this.map.Visibility = System.Windows.Visibility.Visible;
                    break;
            }
        }

    }
}