﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Net;
using System.Xml.Linq;
using System.IO;
using System.Xml;

namespace PushServerDemo
{
    /// <summary>
    /// Rappresents a notification message
    /// </summary>
    public abstract class PushNotification
    {

        /// <summary>
        /// The optional custom header X-MessageID uniquely identifies a notification message. If it is present, the // same value is returned in the notification response
        /// </summary>
        public Guid MessageID { get; set; }

        /// <summary>
        /// Gets or sets the notification class.
        /// </summary>
        /// <value>The notification class.</value>
        public NotificationClass NotificationClass { get; set; }

        internal static XNamespace WPNotificationNamespace = "WPNotification";

        /// <summary>
        /// Encoder used to prepare xml
        /// </summary>
        public static readonly Encoding Encoding = new UTF8Encoding(false);

        /// <summary>
        /// Prepares the header of the webrequest.
        /// </summary>
        /// <param name="headers">The headers.</param>
        internal virtual void PrepareHeader(WebHeaderCollection headers)
        {
            if (Guid.Empty != this.MessageID)
                headers["X-MessageID"] = this.MessageID.ToString();
        }

        /// <summary>
        /// Gets the data to use for POST.
        /// </summary>
        /// <returns></returns>
        internal abstract byte[] GetPostData();

        /// <summary>
        /// Convert document to byte array
        /// </summary>
        /// <param name="doc">The doc.</param>
        /// <returns></returns>
        protected byte[] WriteXml(XDocument doc)
        {
            using (MemoryStream stream = new MemoryStream())
            {
                using (XmlWriter writer = XmlWriter.Create(stream, new XmlWriterSettings
                {
                    Encoding = Encoding,
                }))
                {
                    doc.Save(writer);
                    writer.Flush();

                    return stream.ToArray();
                }
            }
        }
    }

    /// <summary>
    /// Rappresents the batching interval
    /// </summary>
    public enum NotificationClass
    {
        Immediately = 1,
        Within450Seconds = 11,
        Within900Seconds = 21,
    }
}
