﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace PushServerDemo
{
    public class PushNotificationResponse
    {

        internal PushNotificationResponse(Guid messageId, NotificationStatus notificationStatus, DeviceConnectionStatus deviceConnectionStatus, SubscriptionStatus subscriptionStatus)
        {
            this.MessageID = messageId;
            this.NotificationStatus = notificationStatus;
            this.DeviceConnectionStatus = deviceConnectionStatus;
            this.SubscriptionStatus = subscriptionStatus;
        }

        /// <summary>
        /// The optional custom header X-MessageID uniquely identifies a notification message.
        /// </summary>
        public Guid MessageID { get; private set; }

        /// <summary>
        /// Gets or sets the notification status.
        /// </summary>
        /// <value>The notification status.</value>
        public NotificationStatus NotificationStatus { get; private set; }

        /// <summary>
        /// Gets or sets the device connection status.
        /// </summary>
        /// <value>The device connection status.</value>
        public DeviceConnectionStatus DeviceConnectionStatus { get; private set; }

        /// <summary>
        /// Gets or sets the subscription status.
        /// </summary>
        /// <value>The subscription status.</value>
        public SubscriptionStatus SubscriptionStatus { get; private set; }

    }

    public enum NotificationStatus
    {
        /// <summary>
        /// Unkown status
        /// </summary>
        Unknown,
        /// <summary>
        /// The notification request was accepted and queued for delivery.
        /// </summary>
        Received,
        /// <summary>
        /// The notification has refused.
        /// </summary>
        Dropped,
        /// <summary>
        /// Queue overflow. The web service should re-send the notification later. A best practice is to use an exponential backoff algorithm in minute increments.
        /// </summary>
        QueueFull,
        /// <summary>
        /// The push notification was received and dropped by the Push Notification Service. The Suppressed status can occur if the notification channel was configured to suppress push notifications for a particular push notification class.
        /// </summary>
        Suppressed
    }

    public enum DeviceConnectionStatus
    {
        /// <summary>
        /// Unkown status
        /// </summary>
        Unknown,
        Connected,
        InActive,
        Disconnected,
        TempDisconnected,
    }

    public enum SubscriptionStatus
    {
        /// <summary>
        /// Unkown status
        /// </summary>
        Unknown,
        /// <summary>
        /// Subscription is valid
        /// </summary>
        Active,
        /// <summary>
        /// The subscription is invalid and is not present on the Push Notification Service
        /// </summary>
        Expired
    }
}
